@@ -45,7 +45,9 @@ class Renderer:
         self.nco_phase_offset = 0.0
         self.mixer_gain_ratio = 1.0
         self.mixer_phase_offset_degree = 0.0
+        self.delete_acquisition_data_all()
         self.reset()
+        self.trace_enabled = False
 
     def reset(self):
         self.settings = Settings()
@@ -56,12 +58,6 @@ class Renderer:
         self.waves = (None, None)
         self.out0 = []
         self.out1 = []
-        self.acq_count = {
-                i:np.zeros(num_bins, dtype=int) for i,num_bins in self.acq_bins.items()
-                }
-        self.acq_data = {
-                i:np.full((num_bins, 2), np.nan) for i,num_bins in self.acq_bins.items()
-                }
         self.acq_times = {i:[] for i in self.acq_bins}
         self.acq_buffer = AcqBuffer()
         self.mock_data = {}
@@ -81,6 +77,7 @@ class Renderer:
 
     def set_acquisition_bins(self, acq_bins):
         self.acq_bins = acq_bins
+        self.delete_acquisition_data_all()
 
     def set_mrk(self, value):
         self.next_settings.marker = value
@@ -108,6 +105,7 @@ class Renderer:
 
     def play(self, wave0, wave1, wait_after):
         self._update_settings()
+        self._trace(f'Play {wave0} {wave1}')
         if wave0 not in self.wavedict:
             self._error('AWG WAVE PLAYBACK INDEX INVALID PATH 0')
         elif wave1 not in self.wavedict:
@@ -122,11 +120,13 @@ class Renderer:
 
     def acquire(self, bins, bin_index, wait_after):
         self._update_settings()
+        self._trace(f'Acquire {bins} {bin_index}')
         self._add_acquisition(bins, bin_index)
         self._render(wait_after)
 
     def acquire_weighed(self, bins, bin_index, weight0, weight1, wait_after):
         self._update_settings()
+        self._trace(f'AcquireWeighed {bins} {bin_index} {weight0} {weight1}')
         if weight0 not in self.acq_weights:
             self._error('ACQ WEIGHT PLAYBACK INDEX INVALID PATH 0')
         elif weight1 not in self.acq_weights:
@@ -136,6 +136,7 @@ class Renderer:
         self._render(wait_after)
 
     def wait(self, time):
+        self._trace(f'Wait {time}')
         self._render(time)
 
     def wait_sync(self, wait_after):
@@ -147,6 +148,23 @@ class Renderer:
 
     def _update_settings(self):
         new = self.next_settings
+        old = self.settings
+        msg = []
+        if new.awg_gain0 != old.awg_gain0 or new.awg_gain1 != new.awg_gain1:
+            msg.append(f'awg_gain {new.awg_gain0},{new.awg_gain1}')
+        if new.awg_offs0 != old.awg_offs0 or new.awg_offs1 != new.awg_offs1:
+            msg.append(f'awg_offset {new.awg_offs0},{new.awg_offs1}')
+        if new.phase is not None:
+            phase = (new.phase - self.time * self.nco_frequency * 1e-9) % 1
+            self.nco_phase_offset = phase
+            msg.append(f'phase {new.phase}')
+        if new.phase_shift != 0.0:
+            msg.append(f'phase_shift {new.phase_shift}')
+        if new.marker != old.marker:
+            msg.append(f'marker {new.marker:04b}')
+        if len(msg) > 0:
+            self._trace('Update: ' + '; '.join(msg))
+
         if new.phase is not None:
             phase = (new.phase - self.time * self.nco_frequency * 1e-9) % 1
             self.nco_phase_offset = phase
@@ -232,6 +250,17 @@ class Renderer:
                 self._error('OUT OF MOCK DATA')
                 return (np.nan, np.nan)
 
+    def delete_acquisition_data_all(self):
+        self.acq_count = {}
+        self.acq_data = {}
+        for index in self.acq_bins:
+            self.delete_acquisition_data(index)
+
+    def delete_acquisition_data(self, index):
+        num_bins = self.acq_bins[index]
+        self.acq_count[index] = np.zeros(num_bins, dtype=int)
+        self.acq_data[index] = np.full((num_bins, 2), np.nan)
+
     def _add_acquisition(self, bins, bin_index):
         t = self.time
         if bins not in self.acq_bins:
@@ -250,6 +279,10 @@ class Renderer:
                 self.acq_data[bins][bin_index] += value
             self.acq_count[bins][bin_index] += 1
 
+    def _trace(self, msg):
+        if self.trace_enabled:
+            print(f'{self.time:-6} {msg}')
+
     def plot(self, v_max):
         scaling = v_max/2**15
         if self.time > self.max_render_time:
